==> attal_0.8.orig.tar.gz: attal-0.8/i18n/it/attal_server_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Apri</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation>Avvia server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta :</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Scenario errato</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Numero di giocatori connessi errato</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation></translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Errore del server</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Prova di nuovo</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation>Carica il gioco</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation>Salva il gioco</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation>Fine del gioco</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizia</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fine</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/it/attal_server_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Apri</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation>Avvia server</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Host :</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Porta :</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>DisplayScenarii</name>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>Giocatori</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>DisplayScenariiDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>DisplayScenarioDescription</name>
    <message>
        <source>Name: %1</source>
        <translation>Nome: %1</translation>
    </message>
    <message>
        <source>Player(s): %1</source>
        <translation>Giocatore(i): %1</translation>
    </message>
    <message>
        <source>Size: %1x%2</source>
        <translation>Dimensione: %1x%2</translation>
    </message>
    <message>
        <source>Description: %1</source>
        <translation>Descrizione: %1</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Player(s): </source>
        <translation>Giocatore(i):</translation>
    </message>
    <message>
        <source>Size: </source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Descrizione:</translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Scenario errato</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Numero di giocatori connessi errato</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation></translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Errore del server</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Non posso ascoltare i socket.</translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Prova di nuovo</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation type="obsolete">Carica il gioco</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation type="obsolete">Salva il gioco</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation type="obsolete">Fine del gioco</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Non posso caricare il tema</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Il tema </translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation> non è stato caricato con successo</translation>
    </message>
    <message>
        <source>Load Scenario</source>
        <translation type="obsolete">Carica lo scenario</translation>
    </message>
    <message>
        <source>Load Campaign</source>
        <translation type="obsolete">Carica la campagna</translation>
    </message>
    <message>
        <source>Load scenario</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load campaign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill with AI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add AI player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizia</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fine</translation>
    </message>
</context>
</TS>
